<?php
/**
 * BizFolio functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage Pharma_Plus
 * @since 1.0
 */

/**
 * BizFolio only works in WordPress 4.7 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function bizfolio_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed at WordPress.org. See: https://translate.wordpress.org/projects/wp-themes/bizfolio
	 * If you're building a theme based on BizFolio, use a find and replace
	 * to change 'bizfolio' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'bizfolio' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'bizfolio-featured-image', 2000, 1200, true );

	add_image_size( 'bizfolio-thumbnail-avatar', 100, 100, true );

	// Set the default content width.
	$GLOBALS['content_width'] = 525;

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'top'    => __( 'Top Menu', 'bizfolio' ),
		'social' => __( 'Social Links Menu', 'bizfolio' ),
		'footer'    => __( 'Footer Menu', 'bizfolio' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'audio',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', bizfolio_fonts_url() ) );

	// Define and register starter content to showcase the theme on new sites.
	$starter_content = array(
		'widgets' => array(
			// Place three core-defined widgets in the sidebar area.
			'sidebar-1' => array(
				'text_business_info',
				'search',
				'text_about',
			),
		),

		// Specify the core-defined pages to create and add custom thumbnails to some of them.
		'posts' => array(
			'home',
			'about' => array(
				'thumbnail' => '{{image-sandwich}}',
			),
			'contact' => array(
				'thumbnail' => '{{image-espresso}}',
			),
			'blog' => array(
				'thumbnail' => '{{image-coffee}}',
			),
			'homepage-section' => array(
				'thumbnail' => '{{image-espresso}}',
			),
		),

		// Create the custom image attachments used as post thumbnails for pages.
		'attachments' => array(
			'image-espresso' => array(
				'post_title' => _x( 'Espresso', 'Theme starter content', 'bizfolio' ),
				'file' => 'assets/images/espresso.jpg', // URL relative to the template directory.
			),
			'image-sandwich' => array(
				'post_title' => _x( 'Sandwich', 'Theme starter content', 'bizfolio' ),
				'file' => 'assets/images/sandwich.jpg',
			),
			'image-coffee' => array(
				'post_title' => _x( 'Coffee', 'Theme starter content', 'bizfolio' ),
				'file' => 'assets/images/coffee.jpg',
			),
		),

		// Default to a static front page and assign the front and posts pages.
		'options' => array(
			'show_on_front' => 'page',
			'page_on_front' => '{{home}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set the front page section theme mods to the IDs of the core-registered pages.
		'theme_mods' => array(
			'panel_1' => '{{homepage-section}}',
			'panel_2' => '{{about}}',
			'panel_3' => '{{blog}}',
			'panel_4' => '{{contact}}',
		),

		// Set up nav menus for each of the two areas registered in the theme.
		'nav_menus' => array(
			// Assign a menu to the "top" location.
			'top' => array(
				'name' => __( 'Top Menu', 'bizfolio' ),
				'items' => array(
					'link_home', // Note that the core "home" page is actually a link in case a static front page is not used.
					'page_about',
					'page_blog',
					'page_contact',
				),
			),

			// Assign a menu to the "social" location.
			'social' => array(
				'name' => __( 'Social Links Menu', 'bizfolio' ),
				'items' => array(
					'link_yelp',
					'link_facebook',
					'link_twitter',
					'link_instagram',
					'link_email',
				),
			),
		),
	);

	/**
	 * Filters BizFolio array of starter content.
	 *
	 * @since BizFolio 1.1
	 *
	 * @param array $starter_content Array of starter content.
	 */
	$starter_content = apply_filters( 'bizfolio_starter_content', $starter_content );

	add_theme_support( 'starter-content', $starter_content );
}
add_action( 'after_setup_theme', 'bizfolio_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bizfolio_content_width() {

	$content_width = $GLOBALS['content_width'];

	// Get layout.
	$page_layout = get_theme_mod( 'page_layout' );

	// Check if layout is one column.
	if ( 'one-column' === $page_layout ) {
		if ( bizfolio_is_frontpage() ) {
			$content_width = 644;
		} elseif ( is_page() ) {
			$content_width = 740;
		}
	}

	// Check if is single post and there is no sidebar.
	if ( is_single() && ! is_active_sidebar( 'sidebar-1' ) ) {
		$content_width = 740;
	}

	/**
	 * Filter BizFolio content width of the theme.
	 *
	 * @since BizFolio 1.0
	 *
	 * @param int $content_width Content width in pixels.
	 */
	$GLOBALS['content_width'] = apply_filters( 'bizfolio_content_width', $content_width );
}
add_action( 'template_redirect', 'bizfolio_content_width', 0 );

/**
 * Register custom fonts.
 */
function bizfolio_fonts_url() {
	$fonts_url = '';

	/*
	 * Translators: If there are characters in your language that are not
	 * supported by Libre Franklin, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$libre_franklin = _x( 'on', 'Libre Franklin font: on or off', 'bizfolio' );

	if ( 'off' !== $libre_franklin ) {
		$font_families = array();

		$font_families[] = 'Libre Franklin:300,300i,400,400i,600,600i,800,800i';
        $font_families[] = 'Raleway:400,700';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

/**
 * Add preconnect for Google Fonts.
 *
 * @since BizFolio 1.0
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function bizfolio_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'bizfolio-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'bizfolio_resource_hints', 10, 2 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bizfolio_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'bizfolio' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'bizfolio' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer', 'bizfolio' ),
		'id'            => 'footer',
		'description'   => __( 'Add widgets here to appear in your footer.', 'bizfolio' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'bizfolio_widgets_init' );

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since BizFolio 1.0
 *
 * @param string $link Link to single post/page.
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function bizfolio_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'bizfolio' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'bizfolio_excerpt_more' );

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since BizFolio 1.0
 */
function bizfolio_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'bizfolio_javascript_detection', 0 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function bizfolio_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'bizfolio_pingback_header' );

/**
 * Display custom color CSS.
 */
function bizfolio_colors_css_wrap() {
	if ( 'custom' !== get_theme_mod( 'colorscheme' ) && ! is_customize_preview() ) {
		return;
	}

	require_once( get_parent_theme_file_path( '/inc/color-patterns.php' ) );
	$hue = absint( get_theme_mod( 'colorscheme_hue', 250 ) );
?>
	<style type="text/css" id="custom-theme-colors" <?php if ( is_customize_preview() ) { echo 'data-hue="' . $hue . '"'; } ?>>
		<?php echo bizfolio_custom_colors_css(); ?>
	</style>
<?php }
add_action( 'wp_head', 'bizfolio_colors_css_wrap' );

/**
 * Enqueue scripts and styles.
 */
function bizfolio_scripts() {

    // Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'bizfolio-fonts', bizfolio_fonts_url(), array(), null );

	// Theme stylesheet.
	wp_enqueue_style( 'bizfolio-style', get_stylesheet_uri() );

	// Load the dark colorscheme.
	if ( 'dark' === get_theme_mod( 'colorscheme', 'light' ) || is_customize_preview() ) {
		wp_enqueue_style( 'bizfolio-colors-dark', get_theme_file_uri( '/assets/css/colors-dark.css' ), array( 'bizfolio-style' ), '1.0' );
	}

	// Load the Internet Explorer 9 specific stylesheet, to fix display issues in the Customizer.
	if ( is_customize_preview() ) {
		wp_enqueue_style( 'bizfolio-ie9', get_theme_file_uri( '/assets/css/ie9.css' ), array( 'bizfolio-style' ), '1.0' );
		wp_style_add_data( 'bizfolio-ie9', 'conditional', 'IE 9' );
	}

	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'bizfolio-ie8', get_theme_file_uri( '/assets/css/ie8.css' ), array( 'bizfolio-style' ), '1.0' );
	wp_style_add_data( 'bizfolio-ie8', 'conditional', 'lt IE 9' );

	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_theme_file_uri( '/assets/js/html5.js' ), array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'bizfolio-skip-link-focus-fix', get_theme_file_uri( '/assets/js/skip-link-focus-fix.js' ), array(), '1.0', true );

	$bizfolio_l10n = array(
		'quote'          => bizfolio_get_svg( array( 'icon' => 'quote-right' ) ),
	);

	if ( has_nav_menu( 'top' ) ) {
		wp_enqueue_script( 'bizfolio-navigation', get_theme_file_uri( '/assets/js/navigation.js' ), array( 'jquery' ), '1.0', true );
		$bizfolio_l10n['expand']         = __( 'Expand child menu', 'bizfolio' );
		$bizfolio_l10n['collapse']       = __( 'Collapse child menu', 'bizfolio' );
		$bizfolio_l10n['icon']           = bizfolio_get_svg( array( 'icon' => 'angle-down', 'fallback' => true ) );
	}

	wp_enqueue_script( 'bizfolio-global', get_theme_file_uri( '/assets/js/global.js' ), array( 'jquery' ), '1.0', true );

	wp_enqueue_script( 'jquery-scrollto', get_theme_file_uri( '/assets/js/jquery.scrollTo.js' ), array( 'jquery' ), '2.1.2', true );

	wp_localize_script( 'bizfolio-skip-link-focus-fix', 'bizfolioScreenReaderText', $bizfolio_l10n );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'bizfolio_scripts' );

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for content images.
 *
 * @since BizFolio 1.0
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 * @param array  $size  Image size. Accepts an array of width and height
 *                      values in pixels (in that order).
 * @return string A source size value for use in a content image 'sizes' attribute.
 */
function bizfolio_content_image_sizes_attr( $sizes, $size ) {
	$width = $size[0];

	if ( 740 <= $width ) {
		$sizes = '(max-width: 706px) 89vw, (max-width: 767px) 82vw, 740px';
	}

	if ( is_active_sidebar( 'sidebar-1' ) || is_archive() || is_search() || is_home() || is_page() ) {
		if ( ! ( is_page() && 'one-column' === get_theme_mod( 'page_options' ) ) && 767 <= $width ) {
			 $sizes = '(max-width: 767px) 89vw, (max-width: 1000px) 54vw, (max-width: 1071px) 543px, 580px';
		}
	}

	return $sizes;
}
add_filter( 'wp_calculate_image_sizes', 'bizfolio_content_image_sizes_attr', 10, 2 );

/**
 * Filter the `sizes` value in the header image markup.
 *
 * @since BizFolio 1.0
 *
 * @param string $html   The HTML image tag markup being filtered.
 * @param object $header The custom header object returned by 'get_custom_header()'.
 * @param array  $attr   Array of the attributes for the image tag.
 * @return string The filtered header image HTML.
 */
function bizfolio_header_image_tag( $html, $header, $attr ) {
	if ( isset( $attr['sizes'] ) ) {
		$html = str_replace( $attr['sizes'], '100vw', $html );
	}
	return $html;
}
add_filter( 'get_header_image_tag', 'bizfolio_header_image_tag', 10, 3 );

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for post thumbnails.
 *
 * @since BizFolio 1.0
 *
 * @param array $attr       Attributes for the image markup.
 * @param int   $attachment Image attachment ID.
 * @param array $size       Registered image size or flat array of height and width dimensions.
 * @return array The filtered attributes for the image markup.
 */
function bizfolio_post_thumbnail_sizes_attr( $attr, $attachment, $size ) {
	if ( is_archive() || is_search() || is_home() ) {
		$attr['sizes'] = '(max-width: 767px) 89vw, (max-width: 1000px) 54vw, (max-width: 1071px) 543px, 580px';
	} else {
		$attr['sizes'] = '100vw';
	}

	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'bizfolio_post_thumbnail_sizes_attr', 10, 3 );

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 * @since BizFolio 1.0
 *
 * @param string $template front-page.php.
 *
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function bizfolio_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'bizfolio_front_page_template' );

/**
 * Modifies tag cloud widget arguments to display all tags in the same font size
 * and use list format for better accessibility.
 *
 * @since BizFolio 1.4
 *
 * @param array $args Arguments for tag cloud widget.
 * @return array The filtered arguments for tag cloud widget.
 */
function bizfolio_widget_tag_cloud_args( $args ) {
	$args['largest']  = 1;
	$args['smallest'] = 1;
	$args['unit']     = 'em';
	$args['format']   = 'list';

	return $args;
}
add_filter( 'widget_tag_cloud_args', 'bizfolio_widget_tag_cloud_args' );

/**
 * Implement the Custom Header feature.
 */
require get_parent_theme_file_path( '/inc/custom-header.php' );

/**
 * Custom template tags for this theme.
 */
require get_parent_theme_file_path( '/inc/template-tags.php' );

/**
 * Additional features to allow styling of the templates.
 */
require get_parent_theme_file_path( '/inc/template-functions.php' );

/**
 * Customizer additions.
 */
require get_parent_theme_file_path( '/inc/customizer.php' );

/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path( '/inc/icon-functions.php' );

function register_bizfolio_scripts() {
	//REGISTER CSSs
	wp_enqueue_style('bizfolio-bootstrap', get_stylesheet_directory_uri().'/assets/css/bootstrap.min.css');
	wp_enqueue_script('bizfolio-bootstrap-js', get_stylesheet_directory_uri().'/assets/js/bootstrap.min.js');
	wp_enqueue_style('bizfolio-font-awesome-css', get_stylesheet_directory_uri().'/assets/css/fontawesome/css/all.min.css');
	//wp_enqueue_script('bizfolio-custom-js', get_stylesheet_directory_uri().'/js/common.js');
}
add_action('wp_enqueue_scripts', 'register_bizfolio_scripts', 30);

/**
 * Allows to setup additional detail (contact, social) for BizFolio theme.
 */
function bizfolio_customizer( $wp_customize ) {

    // Adds additional details section to customizer
    $wp_customize->add_section(
        'bizfolio_additional_settings',
        array(
            'title' => __( 'BizFolio Additional Settings', 'bizfolio' ),
            'description' => __( 'This is an additional settings for BizFolio Theme.', 'bizfolio' ),
            'priority' => 150,
        )
	);
	
	// Adds 'Color Scheme' field to customizer
	$wp_customize->add_setting(
        'bizfolio_color_scheme', array(
			'default' => "#99374c",
			'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'bizfolio_color_scheme', 
            array(
				'label' => __('Color Scheme', 'bizfolio'), 
            	'section' => 'bizfolio_additional_settings',
			)
        )
    );

    // Adds 'Phone' field to customizer
    $wp_customize->add_setting(
        'bizfolio_phone',
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'bizfolio_phone',
        array(
            'type' => 'text',
            'label' => __( 'Phone', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
    );

    // Adds 'Email' field to customizer
    $wp_customize->add_setting(
        'bizfolio_email',
        array(
            'sanitize_callback' => 'is_email',
        )
    );
    $wp_customize->add_control(
        'bizfolio_email',
        array(
            'type' => 'text',
            'label' => __( 'Email', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
    );

    // Adds 'Address' field to customizer
    $wp_customize->add_setting(
        'bizfolio_address',
        array(
            'sanitize_callback' => 'esc_textarea',
        )
    );
    $wp_customize->add_control(
        'bizfolio_address',
        array(
            'type' => 'textarea',
            'label' => __( 'Address', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
    );

    // Adds 'Facebook Link' field to customizer
    $wp_customize->add_setting(
        'bizfolio_facebook_link',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'bizfolio_facebook_link',
        array(
            'type' => 'text',
            'label' => __( 'Facebook Link', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
    );

    // Adds 'Twiiter Link' field to customizer
    $wp_customize->add_setting(
        'bizfolio_twitter_link',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'bizfolio_twitter_link',
        array(
            'type' => 'text',
            'label' => __( 'Twiiter Link', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
    );

    // Adds 'Instagram Link' field to customizer
    $wp_customize->add_setting(
        'bizfolio_instagram_link',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'bizfolio_instagram_link',
        array(
            'type' => 'text',
            'label' => __( 'Instagram Link', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
    );

    // Adds 'Youtube Link' field to customizer
    $wp_customize->add_setting(
        'bizfolio_youtube_link',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'bizfolio_youtube_link',
        array(
            'type' => 'text',
            'label' => __( 'Youtube Link', 'bizfolio' ),
            'section' => 'bizfolio_additional_settings',
        )
	);
}
add_action( 'customize_register', 'bizfolio_customizer' );

function bizfolio_customizer_css(){
	$color_scheme = get_theme_mod('bizfolio_color_scheme', '#99374c');
	?>
		<style type="text/css">
			.navigation-top .current-menu-item > a, .navigation-top .current_page_item > a,
			.main-navigation a:hover, .top-contact .cotnact-btn > a:hover, .bizfolio-btn:hover,
			.back_to_top > a:hover, .social-links > a:hover, body a:hover {
				color: <?php echo $color_scheme; ?>;
			}
			.site-header {
				box-shadow: 0 -12px 24px 2px <?php echo $color_scheme; ?>;
			}
			.search-form .search-submit,
			.main-navigation li li:hover, .main-navigation li li.focus,
			.parallax-bg .bizfolio-btn, .bizfolio-title-with-underline:after,
			.header-title:after, .entry-title:after, .page-title:after {
				background-color: <?php echo $color_scheme; ?>;
			}
		</style>
    <?php
}
add_action( 'wp_head', 'bizfolio_customizer_css');